@@ -55,10 +55,9 @@ class GraphWidget(DOMWidget):
     -------
     .. code::
 
-       In [1]: from yfiles_jupyter_graphs import GraphWidget
-       In [2]: w = GraphWidget()
-       In [3]: w
-       Out[3]: ...
+       from yfiles_jupyter_graphs import GraphWidget
+       w = GraphWidget()
+       w.show()
 
     See notebooks for more examples.
 
@@ -67,24 +66,7 @@ class GraphWidget(DOMWidget):
     Nodes and edges properties should be constructed recursively with basic python types
     otherwise {de-}serializers will fail.
 
-    References
-    ----------
-    `ipywidget docs <https://ipywidgets.readthedocs.io/en/stable/index.html>`_
-
-    `ipywidgets styling docs <https://ipywidgets.readthedocs.io/en/latest/examples/Widget%20Styling.html>`_
-
-    `ipywidgets layout class <https://github.com/jupyter-widgets/ipywidgets/blob/master/python/ipywidgets/
-    ipywidgets/widgets/widget_layout.py>`_
-
-    `ipywidgets docs custom serialization <https://ipywidgets.readthedocs.io/en/
-    stable/examples/Widget%20Low%20Level.html#Custom-serialization-and-de-serialization-on-the-JavaScript-side>`_
     """
-    # TODO add comment about
-    #  multiple widgets,
-    #  run all behaviour,
-    #  mappings in general,
-    #  export/update of properties (e.g. comms callbacks)
-    # TODO add few more references in comments
     _model_name = Unicode('GraphModel').tag(sync=True)
     _model_module = Unicode(module_name).tag(sync=True)
     _model_module_version = Unicode(module_version).tag(sync=True)
@@ -141,7 +123,6 @@ class GraphWidget(DOMWidget):
         -----
         This function acts as an alias for using GraphWidget.nodes property
         e.g. w.nodes == w.get_nodes().
-        This is motivated by the problems of providing docstrings for traitlets.
 
         Returns
         -------
@@ -167,18 +148,17 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: w.set_nodes([
-                        {'id': 0, 'properties': {'label': 'Hello World'}},
-                        {'id': 1, 'properties': {'label': 'This is a second node.'}}
-                   ])
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           w.set_nodes([
+                {'id': 0, 'properties': {'label': 'Hello World'}},
+                {'id': 1, 'properties': {'label': 'This is a second node.'}}
+           ])
 
         Notes
         -----
         This function acts as an alias for using GraphWidget.nodes property
         e.g. w.nodes = [{...}] has the same effect as using w.set_nodes([{...}]).
-        This is motivated by the problems of providing docstrings for traitlets.
 
         Returns
         -------
@@ -195,7 +175,6 @@ class GraphWidget(DOMWidget):
         -----
         This function acts as an alias for using GraphWidget.edges property
         e.g. w.edges == w.get_edges() is true.
-        This is motivated by the problems of providing docstrings for traitlets.
 
         Returns
         -------
@@ -224,17 +203,16 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: w.set_edges([
-                       {'id': 0, 'start': 0, 'end': 1, 'properties': {'label': 'edge between first and second node'}}
-                   ])
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           w.set_edges([
+               {'id': 0, 'start': 0, 'end': 1, 'properties': {'label': 'edge between first and second node'}}
+           ])
 
         Notes
         -----
         This function acts as an alias for using GraphWidget.edges property
         e.g. w.edges = [{...}] has the same effect as using w.set_edges([{...}]).
-        This is motivated by the problems of providing docstrings for traitlets.
 
         Returns
         -------
@@ -251,7 +229,6 @@ class GraphWidget(DOMWidget):
         -----
         This function acts as an alias for using GraphWidget.directed property
         e.g. w.directed == w.get_directed() is true.
-        This is motivated by the problems of providing docstrings for traitlets.
 
         Returns
         -------
@@ -273,7 +250,6 @@ class GraphWidget(DOMWidget):
         -----
         This function acts as an alias for using GraphWidget.directed property
         e.g. w.directed = x has the same effect as using w.set_directed(x).
-        This is motivated by the problems of providing docstrings for traitlets.
 
         Returns
         -------
@@ -312,11 +288,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_node_label_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_node_label_mapping(custom_node_label_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_node_label_mapping(index: int, node: dict):
+           ...
+           w.set_node_label_mapping(custom_node_label_mapping)
 
         Returns
         -------
@@ -367,11 +343,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_edge_label_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_edge_label_mapping(custom_edge_label_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_edge_label_mapping(index: int, node: dict):
+           ...
+           w.set_edge_label_mapping(custom_edge_label_mapping)
 
         Returns
         -------
@@ -426,11 +402,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_node_property_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_node_property_mapping(custom_node_property_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_node_property_mapping(index: int, node: dict):
+           ...
+           w.set_node_property_mapping(custom_node_property_mapping)
 
         Returns
         -------
@@ -485,11 +461,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_edge_property_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_edge_property_mapping(custom_edge_property_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_edge_property_mapping(index: int, node: dict):
+           ...
+           w.set_edge_property_mapping(custom_edge_property_mapping)
 
         Returns
         -------
@@ -540,11 +516,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_node_color_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_node_color_mapping(custom_node_color_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_node_color_mapping(index: int, node: dict):
+           ...
+           w.set_node_color_mapping(custom_node_color_mapping)
 
         Returns
         -------
@@ -595,11 +571,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_edge_color_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_edge_color_mapping(custom_edge_color_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_edge_color_mapping(index: int, node: dict):
+           ...
+           w.set_edge_color_mapping(custom_edge_color_mapping)
 
         Returns
         -------
@@ -650,11 +626,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_node_scale_factor_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_node_scale_factor_mapping(custom_node_scale_factor_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_node_scale_factor_mapping(index: int, node: dict):
+           ...
+           w.set_node_scale_factor_mapping(custom_node_scale_factor_mapping)
 
         Returns
         -------
@@ -706,11 +682,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_edge_thickness_factor_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_edge_thickness_factor_mapping(custom_edge_thickness_factor_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_edge_thickness_factor_mapping(index: int, node: dict):
+           ...
+           w.set_edge_thickness_factor_mapping(custom_edge_thickness_factor_mapping)
 
         Returns
         -------
@@ -766,11 +742,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_node_type_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_node_type_mapping(custom_node_type_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_node_type_mapping(index: int, node: dict):
+           ...
+           w.set_node_type_mapping(custom_node_type_mapping)
 
         References
         ----------
@@ -830,11 +806,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_node_position_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_node_position_mapping(custom_node_position_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_node_position_mapping(index: int, node: dict):
+           ...
+           w.set_node_position_mapping(custom_node_position_mapping)
 
         Returns
         -------
@@ -885,11 +861,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_directed_mapping(index: int, node: dict):
-                    ...
-           In [4]: w.set_directed_mapping(custom_directed_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_directed_mapping(index: int, node: dict):
+           ...
+           w.set_directed_mapping(custom_directed_mapping)
 
         Returns
         -------
@@ -962,11 +938,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_element_label_mapping(index: int, element: typing.Dict):
-                    ...
-           In [4]: w.set_{node|edge}_label_mapping(custom_element_label_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_element_label_mapping(index: int, element: typing.Dict):
+           ...
+           w.set_{node|edge}_label_mapping(custom_element_label_mapping)
 
         Returns
         -------
@@ -1003,11 +979,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_element_property_mapping(index: int, element: typing.Dict):
-                    ...
-           In [4]: w.set_{node|edge}_property_mapping(custom_element_property_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_element_property_mapping(index: int, element: typing.Dict):
+           ...
+           w.set_{node|edge}_property_mapping(custom_element_property_mapping)
 
         Parameters
         ----------
@@ -1053,11 +1029,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_node_color_mapping(index: int, node: typing.Dict):
-                    ...
-           In [4]: w.set_node_color_mapping(custom_node_color_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_node_color_mapping(index: int, node: typing.Dict):
+           ...
+           w.set_node_color_mapping(custom_node_color_mapping)
 
         Returns
         -------
@@ -1095,11 +1071,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_edge_color_mapping(index: int, edge: typing.Dict):
-                    ...
-           In [4]: w.set_edge_color_mapping(custom_edge_color_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_edge_color_mapping(index: int, edge: typing.Dict):
+           ...
+           w.set_edge_color_mapping(custom_edge_color_mapping)
 
         Returns
         -------
@@ -1137,11 +1113,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_node_scale_factor_mapping(index: int, node: typing.Dict):
-                    ...
-           In [4]: w.set_node_scale_factor_mapping(custom_node_scale_factor_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_node_scale_factor_mapping(index: int, node: typing.Dict):
+           ...
+           w.set_node_scale_factor_mapping(custom_node_scale_factor_mapping)
 
         Returns
         -------
@@ -1172,11 +1148,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_edge_thickness_factor_mapping(index: int, edge: typing.Dict):
-                    ...
-           In [4]: w.set_edge_thickness_factor_mapping(custom_edge_thickness_factor_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_edge_thickness_factor_mapping(index: int, edge: typing.Dict):
+           ...
+           w.set_edge_thickness_factor_mapping(custom_edge_thickness_factor_mapping)
 
         Returns
         -------
@@ -1207,11 +1183,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_node_type_mapping(index: int, node: typing.Dict):
-                    ...
-           In [4]: w.set_node_type_mapping(custom_node_type_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_node_type_mapping(index: int, node: typing.Dict):
+           ...
+           w.set_node_type_mapping(custom_node_type_mapping)
 
         Returns
         -------
@@ -1242,11 +1218,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_node_position_mapping(index: int, node: typing.Dict):
-                    ...
-           In [4]: w.set_node_position_mapping(custom_node_position_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_node_position_mapping(index: int, node: typing.Dict):
+           ...
+           w.set_node_position_mapping(custom_node_position_mapping)
 
         Returns
         -------
@@ -1276,11 +1252,11 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-           In [1]: from yfiles_jupyter_graphs import GraphWidget
-           In [2]: w = GraphWidget()
-           In [3]: def custom_directed_mapping(index: int, edge: typing.Dict):
-                    ...
-           In [4]: w.set_directed_mapping(custom_directed_mapping)
+           from yfiles_jupyter_graphs import GraphWidget
+           w = GraphWidget()
+           def custom_directed_mapping(index: int, edge: typing.Dict):
+           ...
+           w.set_directed_mapping(custom_directed_mapping)
 
         Returns
         -------
@@ -1511,10 +1487,10 @@ class GraphWidget(DOMWidget):
         -------
         .. code::
 
-            In [1]: from networkx import florentine_families_graph
-            In [2]: from yfiles_jupyter_graphs import GraphWidget
-            In [3]: w = GraphWidget()
-            In [4]: w.import_graph(florentine_families_graph())
+            from networkx import florentine_families_graph
+            from yfiles_jupyter_graphs import GraphWidget
+            w = GraphWidget()
+            w.import_graph(florentine_families_graph())
 
         Notes
         -----
@@ -1537,7 +1513,6 @@ class GraphWidget(DOMWidget):
         -----
         This function acts as an alias for using GraphWidget.graph_layout property
         e.g. w.graph_layout == w.get_graph_layout() is true.
-        This is motivated by the problems of providing docstrings for traitlets.
 
         Returns
         -------
